pub struct AdminUsersSession {
pub client: Client,
}Fields
client: ClientImplementations
Sourceimpl AdminUsersSession
impl AdminUsersSession
Sourcepub async fn invalidate(&self) -> Result<Response<DndEndSchema>, ClientError>
pub async fn invalidate(&self) -> Result<Response<DndEndSchema>, ClientError>
This function performs a POST to the /admin.users.session.invalidate endpoint.
Invalidate a single session for a user by session_id
FROM: https://api.slack.com/methods/admin.users.session.invalidate
Parameters:
token: &str– Authentication token. Requires scope:admin.users:write.
Sourcepub async fn reset(&self) -> Result<Response<DndEndSchema>, ClientError>
pub async fn reset(&self) -> Result<Response<DndEndSchema>, ClientError>
This function performs a POST to the /admin.users.session.reset endpoint.
Wipes all valid sessions on all devices for a given user
FROM: https://api.slack.com/methods/admin.users.session.reset
Parameters:
token: &str– Authentication token. Requires scope:admin.users:write.