pub struct AppsPermissionsUsers {
pub client: Client,
}Fields
client: ClientImplementations
Sourceimpl AppsPermissionsUsers
impl AppsPermissionsUsers
Sourcepub async fn list(
&self,
cursor: &str,
limit: i64,
) -> Result<Response<DndEndSchema>, ClientError>
pub async fn list( &self, cursor: &str, limit: i64, ) -> Result<Response<DndEndSchema>, ClientError>
This function performs a GET to the /apps.permissions.users.list endpoint.
Returns list of user grants and corresponding scopes this app has on a team.
FROM: https://api.slack.com/methods/apps.permissions.users.list
Parameters:
token: &str– Authentication token. Requires scope:none.cursor: &str– Paginate through collections of data by setting thecursorparameter to anext_cursorattribute returned by a previous request’sresponse_metadata. Default value fetches the first “page” of the collection. See pagination for more detail.limit: i64– The maximum number of items to return.
Sourcepub async fn request(
&self,
scopes: &str,
trigger_id: &str,
user: &str,
) -> Result<Response<DndEndSchema>, ClientError>
pub async fn request( &self, scopes: &str, trigger_id: &str, user: &str, ) -> Result<Response<DndEndSchema>, ClientError>
This function performs a GET to the /apps.permissions.users.request endpoint.
Enables an app to trigger a permissions modal to grant an app access to a user access scope.
FROM: https://api.slack.com/methods/apps.permissions.users.request
Parameters:
token: &str– Authentication token. Requires scope:none.scopes: &str– A comma separated list of user scopes to request for.trigger_id: &str– Token used to trigger the request.user: &str– The user this scope is being requested for.