pub struct ApiMethodUsersGetPresence {
pub auto_away: bool,
pub connection_count: i64,
pub last_activity: i64,
pub manual_away: bool,
pub ok: bool,
pub online: bool,
pub presence: String,
}Expand description
Generated from users.getPresence with shasum e7251aec575d8863f9e0eb38663ae9dc26655f65
Fields
auto_away: boolGenerated from users.getPresence with shasum e7251aec575d8863f9e0eb38663ae9dc26655f65
connection_count: i64Generated from users.getPresence with shasum e7251aec575d8863f9e0eb38663ae9dc26655f65
last_activity: i64Generated from users.getPresence with shasum e7251aec575d8863f9e0eb38663ae9dc26655f65
manual_away: boolGenerated from users.getPresence with shasum e7251aec575d8863f9e0eb38663ae9dc26655f65
ok: boolonline: boolGenerated from users.getPresence with shasum e7251aec575d8863f9e0eb38663ae9dc26655f65
presence: StringTrait Implementations
Sourceimpl Clone for ApiMethodUsersGetPresence
impl Clone for ApiMethodUsersGetPresence
Sourcefn clone(&self) -> ApiMethodUsersGetPresence
fn clone(&self) -> ApiMethodUsersGetPresence
Returns a duplicate of the value. Read more
1.0.0 · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreSourceimpl Debug for ApiMethodUsersGetPresence
impl Debug for ApiMethodUsersGetPresence
Sourceimpl<'de> Deserialize<'de> for ApiMethodUsersGetPresence
impl<'de> Deserialize<'de> for ApiMethodUsersGetPresence
Sourcefn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
fn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
Deserialize this value from the given Serde deserializer. Read more
Sourceimpl JsonSchema for ApiMethodUsersGetPresence
impl JsonSchema for ApiMethodUsersGetPresence
Sourcefn schema_name() -> String
fn schema_name() -> String
The name of the generated JSON Schema. Read more
Sourcefn schema_id() -> Cow<'static, str>
fn schema_id() -> Cow<'static, str>
Returns a string that uniquely identifies the schema produced by this type. Read more
Sourcefn json_schema(generator: &mut SchemaGenerator) -> Schema
fn json_schema(generator: &mut SchemaGenerator) -> Schema
Generates a JSON Schema for this type. Read more
Sourcefn is_referenceable() -> bool
fn is_referenceable() -> bool
Whether JSON Schemas generated for this type should be re-used where possible using the
$ref keyword. Read moreimpl StructuralPartialEq for ApiMethodUsersGetPresence