pub struct ItemsAnyOf {
pub items: Items,
pub message_pin: MessagePin,
}Expand description
All of the following types are flattened into one object:
ItemsMessagePin
Fields
items: Itemsmessage_pin: MessagePinTrait Implementations
Sourceimpl Clone for ItemsAnyOf
impl Clone for ItemsAnyOf
Sourcefn clone(&self) -> ItemsAnyOf
fn clone(&self) -> ItemsAnyOf
Returns a duplicate of the value. Read more
1.0.0 · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreSourceimpl Debug for ItemsAnyOf
impl Debug for ItemsAnyOf
Sourceimpl<'de> Deserialize<'de> for ItemsAnyOf
impl<'de> Deserialize<'de> for ItemsAnyOf
Sourcefn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
fn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
Deserialize this value from the given Serde deserializer. Read more
Sourceimpl JsonSchema for ItemsAnyOf
impl JsonSchema for ItemsAnyOf
Sourcefn schema_name() -> String
fn schema_name() -> String
The name of the generated JSON Schema. Read more
Sourcefn schema_id() -> Cow<'static, str>
fn schema_id() -> Cow<'static, str>
Returns a string that uniquely identifies the schema produced by this type. Read more
Sourcefn json_schema(generator: &mut SchemaGenerator) -> Schema
fn json_schema(generator: &mut SchemaGenerator) -> Schema
Generates a JSON Schema for this type. Read more
Sourcefn is_referenceable() -> bool
fn is_referenceable() -> bool
Whether JSON Schemas generated for this type should be re-used where possible using the
$ref keyword. Read moreSourceimpl PartialEq for ItemsAnyOf
impl PartialEq for ItemsAnyOf
Sourceimpl Serialize for ItemsAnyOf
impl Serialize for ItemsAnyOf
impl StructuralPartialEq for ItemsAnyOf