pub struct ObjsConversationAnyOf {
pub objs_conversation: ObjsConversation,
pub conversation_mpim_object: ConversationMpimObject,
pub conversation_im_channel_object_from_conversations_methods: ConversationImChannelObjectFromConversationsMethods,
}Expand description
All of the following types are flattened into one object:
ObjsConversationConversationMpimObjectConversationImChannelObjectFromConversationsMethods
Fields
objs_conversation: ObjsConversationconversation_mpim_object: ConversationMpimObjectconversation_im_channel_object_from_conversations_methods: ConversationImChannelObjectFromConversationsMethodsTrait Implementations
Sourceimpl Clone for ObjsConversationAnyOf
impl Clone for ObjsConversationAnyOf
Sourcefn clone(&self) -> ObjsConversationAnyOf
fn clone(&self) -> ObjsConversationAnyOf
Returns a duplicate of the value. Read more
1.0.0 · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreSourceimpl Debug for ObjsConversationAnyOf
impl Debug for ObjsConversationAnyOf
Sourceimpl<'de> Deserialize<'de> for ObjsConversationAnyOf
impl<'de> Deserialize<'de> for ObjsConversationAnyOf
Sourcefn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
fn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
Deserialize this value from the given Serde deserializer. Read more
Sourceimpl JsonSchema for ObjsConversationAnyOf
impl JsonSchema for ObjsConversationAnyOf
Sourcefn schema_name() -> String
fn schema_name() -> String
The name of the generated JSON Schema. Read more
Sourcefn schema_id() -> Cow<'static, str>
fn schema_id() -> Cow<'static, str>
Returns a string that uniquely identifies the schema produced by this type. Read more
Sourcefn json_schema(generator: &mut SchemaGenerator) -> Schema
fn json_schema(generator: &mut SchemaGenerator) -> Schema
Generates a JSON Schema for this type. Read more
Sourcefn is_referenceable() -> bool
fn is_referenceable() -> bool
Whether JSON Schemas generated for this type should be re-used where possible using the
$ref keyword. Read moreSourceimpl PartialEq for ObjsConversationAnyOf
impl PartialEq for ObjsConversationAnyOf
Sourceimpl Serialize for ObjsConversationAnyOf
impl Serialize for ObjsConversationAnyOf
impl StructuralPartialEq for ObjsConversationAnyOf