pub struct ScheduledMessages {
pub channel_id: String,
pub date_created: i64,
pub id: String,
pub post_at: i64,
pub text: String,
}Fields
channel_id: Stringdate_created: i64id: Stringpost_at: i64text: StringTrait Implementations
Sourceimpl Clone for ScheduledMessages
impl Clone for ScheduledMessages
Sourcefn clone(&self) -> ScheduledMessages
fn clone(&self) -> ScheduledMessages
Returns a duplicate of the value. Read more
1.0.0 (const: unstable) · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreSourceimpl Debug for ScheduledMessages
impl Debug for ScheduledMessages
Sourceimpl<'de> Deserialize<'de> for ScheduledMessages
impl<'de> Deserialize<'de> for ScheduledMessages
Sourcefn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
fn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
Deserialize this value from the given Serde deserializer. Read more
Sourceimpl JsonSchema for ScheduledMessages
impl JsonSchema for ScheduledMessages
Sourcefn schema_name() -> String
fn schema_name() -> String
The name of the generated JSON Schema. Read more
Sourcefn schema_id() -> Cow<'static, str>
fn schema_id() -> Cow<'static, str>
Returns a string that uniquely identifies the schema produced by this type. Read more
Sourcefn json_schema(generator: &mut SchemaGenerator) -> Schema
fn json_schema(generator: &mut SchemaGenerator) -> Schema
Generates a JSON Schema for this type. Read more
Sourcefn is_referenceable() -> bool
fn is_referenceable() -> bool
Whether JSON Schemas generated for this type should be re-used where possible using the
$ref keyword. Read moreSourceimpl PartialEq for ScheduledMessages
impl PartialEq for ScheduledMessages
Sourcefn eq(&self, other: &ScheduledMessages) -> bool
fn eq(&self, other: &ScheduledMessages) -> bool
Tests for
self and other values to be equal, and is used by ==.Sourceimpl Serialize for ScheduledMessages
impl Serialize for ScheduledMessages
impl StructuralPartialEq for ScheduledMessages